==> adminer-2.3.2.tbz: www/adminer/adminer/lang/zh.inc.php <==
<?php
$translations = array(
	'Login' => '登录',
	'Logout successful.' => '注销成功。',
	'Invalid credentials.' => '无效凭据。',
	'Server' => '服务器',
	'Username' => '用户名',
	'Password' => '密码',
	'Select database' => '选择数据库',
	'Invalid database.' => '无效数据库。',
	'Create new database' => '创建新数据库',
	'Table has been dropped.' => '已丢弃表。',
	'Table has been altered.' => '已更改表。',
	'Table has been created.' => '已创建表。',
	'Alter table' => '更改表',
	'Create table' => '创建表',
	'Table name' => '表名',
	'engine' => '引擎',
	'collation' => '校对',
	'Column name' => '列名',
	'Type' => '类型',
	'Length' => '长度',
	'Auto Increment' => '自动增量',
	'Options' => '选项',
	'Save' => '保存',
	'Drop' => '丢弃',
	'Database has been dropped.' => '已丢弃数据库。',
	'Database has been created.' => '已创建数据库。',
	'Database has been renamed.' => '已重命名数据库。',
	'Database has been altered.' => '已更改数据库。',
	'Alter database' => '更改数据库',
	'Create database' => '创建数据库',
	'SQL command' => 'SQL命令',
	'Dump' => '导出',
	'Logout' => '注销',
	'database' => '数据库',
	'Use' => '使用',
	'No tables.' => '没有表。',
	'select' => '选择',
	'Create new table' => '创建新表',
	'Item has been deleted.' => '已删除项目。',
	'Item has been updated.' => '已更新项目。',
	'Item has been inserted.' => '已插入项目。',
	'Edit' => '编辑',
	'Insert' => '插入',
	'Save and insert next' => '保存并插入下一个',
	'Delete' => '删除',
	'Database' => '数据库',
	'Routines' => '子程序',
	'Indexes have been altered.' => '已更改索引。',
	'Indexes' => '索引',
	'Alter indexes' => '更改索引',
	'Add next' => '添加下一个',
	'Language' => '语言',
	'Select' => '选择',
	'New item' => '新建项',
	'Search' => '搜索',
	'Sort' => '排序',
	'descending' => '降序',
	'Limit' => '限定',
	'No rows.' => '没有行。',
	'Action' => '动作',
	'edit' => '编辑',
	'Page' => '页面',
	'Query executed OK, %d row(s) affected.' => '执行查询OK，%d 行受影响',
	'Error in query' => '查询出错',
	'Execute' => '执行',
	'Table' => '表',
	'Foreign keys' => '外键',
	'Triggers' => '触发器',
	'View' => '视图',
	'Unable to select the table' => '不能选择该表',
	'Invalid CSRF token. Send the form again.' => '无效 CSRF 令牌。重新发送表单。',
	'Comment' => '注释',
	'Default values' => '默认值',
	'Show column comments' => '显示列注释',
	'%d byte(s)' => '%d 字节',
	'No commands to execute.' => '没有命令执行。',
	'Unable to upload a file.' => '不能上传文件。',
	'File upload' => '文件上传',
	'File uploads are disabled.' => '文件上传被禁用。',
	'Routine has been called, %d row(s) affected.' => '子程序被调用，%d 行被影响',
	'Call' => '调用',
	'No MySQL extension' => '没有MySQL扩展',
	'None of the supported PHP extensions (%s) are available.' => '没有支持的 PHP 扩展可用（%s）。',
	'Session support must be enabled.' => '会话必须被启用。',
	'Session expired, please login again.' => '会话已过期，请重新登录。',
	'Text length' => '文本长度',
	'Foreign key has been dropped.' => '已删除外键。',
	'Foreign key has been altered.' => '已更改外键。',
	'Foreign key has been created.' => '已创建外键。',
	'Foreign key' => '外键',
	'Target table' => '目标表',
	'Change' => '更改',
	'Source' => '源',
	'Target' => '目标',
	'Add column' => '增加列',
	'Alter' => '更改',
	'Add foreign key' => '添加外键',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => '索引类型',
	'Column (length)' => '列（长度）',
	'View has been dropped.' => '已丢弃视图。',
	'View has been altered.' => '已更改视图。',
	'View has been created.' => '已创建视图。',
	'Alter view' => '更改视图',
	'Create view' => '创建视图',
	'Name' => '名称',
	'Process list' => '进程列表',
	'%d process(es) have been killed.' => '%d 个进程被终止',
	'Kill' => '终止',
	'Parameter name' => '参数名',
	'Database schema' => '数据库概要',
	'Create procedure' => '创建过程',
	'Create function' => '创建函数',
	'Routine has been dropped.' => '已丢弃子程序。',
	'Routine has been altered.' => '已更改子程序。',
	'Routine has been created.' => '已创建子程序。',
	'Alter function' => '更改函数',
	'Alter procedure' => '更改过程',
	'Return type' => '返回类型',
	'Add trigger' => '创建触发器',
	'Trigger has been dropped.' => '已丢弃触发器。',
	'Trigger has been altered.' => '已更改触发器。',
	'Trigger has been created.' => '已创建触发器。',
	'Alter trigger' => '更改触发器',
	'Create trigger' => '创建触发器',
	'Time' => '时间',
	'Event' => '事件',
	'MySQL version: %s through PHP extension %s' => 'MySQL 版本：%s 通过 PHP 扩展 %s',
	'%d row(s)' => '%d 行',
	'~ %s' => '~ %s',
	'Remove' => '移除',
	'Are you sure?' => '你确定吗？',
	'Privileges' => '权限',
	'Create user' => '创建用户',
	'User has been dropped.' => '已丢弃用户。',
	'User has been altered.' => '已更改用户。',
	'User has been created.' => '已创建用户。',
	'Hashed' => 'Hashed',
	'Column' => '列',
	'Routine' => '子程序',
	'Grant' => '授权',
	'Revoke' => '废除',
	'Logged as: %s' => '登录为：%s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => '太大的 POST 数据。减少数据或者增加 %s 配置命令。',
	'Move up' => '上移',
	'Move down' => '下移',
	'Export' => '导出',
	'Tables' => '表',
	'Data' => '数据',
	'Output' => '输出',
	'open' => '打开',
	'save' => '保存',
	'Format' => '格式',
	'Functions' => '函数',
	'Aggregation' => '集合',
	'Event has been dropped.' => '已丢弃事件。',
	'Event has been altered.' => '已更改事件。',
	'Event has been created.' => '已创建事件。',
	'Alter event' => '更改事件',
	'Create event' => '创建事件',
	'Start' => '开始',
	'End' => '结束',
	'Every' => '每',
	'Status' => '状态',
	'On completion preserve' => '完成后保存',
	'Events' => '事件',
	'Schedule' => '调度',
	'At given time' => '在指定时间',
	'Tables have been truncated.' => '已清空表。',
	'Tables have been moved.' => '已转移表。',
	'Tables and views' => '表和视图',
	'Engine' => '引擎',
	'Collation' => '校对',
	'Data Length' => '数据长度',
	'Index Length' => '索引长度',
	'Data Free' => '数据空闲',
	'Rows' => '行数',
	',' => ',',
	'Analyze' => '分析',
	'Optimize' => '优化',
	'Check' => '检查',
	'Repair' => '修复',
	'Truncate' => '清空',
	'Move to other database' => '转移到其它数据库',
	'Move' => '转移',
	'Save and continue edit' => '保存并继续编辑',
	'original' => '原始',
	'%d item(s) have been affected.' => '%d 个项目受到影响。',
	'whole result' => '所有结果',
	'Tables have been dropped.' => '已丢弃表。',
	'Clone' => '克隆',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => '超过最多允许的字段数量。请增加 %s 和 %s 。',
	'Partition by' => '分区类型',
	'Partitions' => '分区',
	'Partition name' => '分区名',
	'Values' => '值',
	'%d row(s) have been imported.' => '%d 行已导入。',
	'Show structure' => '表结构',
	'(anywhere)' => '（任意位置）',
	'CSV Import' => 'CSV 导入',
	'Import' => '导入',
	'Stop on error' => '出错时停止',
	'Select data' => '选择表',
	'%.3f s' => '%.3f 秒',
	'$1-$3-$5' => '$1.$3.$5',
	'[yyyy]-mm-dd' => '[yyyy].mm.dd',
	'History' => '历史',
	'Variables' => '变量',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => '源列和目标列必须具有相同的数据类型，在目标列上必须有一个索引并且引用的数据必须存在。',
	'Relations' => '关联信息',
	'Run file' => '运行文件',
	'Clear' => '清除',
	'Maximum allowed file size is %sB.' => '最多允许的文件大小为 %sB',
	'Numbers' => '数字',
	'Date and time' => '日期时间',
	'Strings' => '字符串',
	'Binary' => '二进制',
	'Lists' => '列表',
	'Editor' => '编辑器',
	'E-mail' => '电子邮件',
	'From' => '来自',
	'Subject' => '主题',
	'Send' => '发送',
	'%d e-mail(s) have been sent.' => '%d 封邮件已发送。',
	'Webserver file %s' => 'Web服务器文件 %s',
	'File does not exist.' => '文件不存在',
	'%d in total' => '共计 %d',
	'Permanent login' => '保持登录',
);

==> adminer-3.1.0_1.tbz: www/adminer/adminer/lang/zh.inc.php <==
<?php
$translations = array(
	'Login' => '登录',
	'Logout successful.' => '注销成功。',
	'Invalid credentials.' => '无效凭据。',
	'Server' => '服务器',
	'Username' => '用户名',
	'Password' => '密码',
	'Select database' => '选择数据库',
	'Invalid database.' => '无效数据库。',
	'Create new database' => '创建新数据库',
	'Table has been dropped.' => '已丢弃表。',
	'Table has been altered.' => '已更改表。',
	'Table has been created.' => '已创建表。',
	'Alter table' => '更改表',
	'Create table' => '创建表',
	'Table name' => '表名',
	'engine' => '引擎',
	'collation' => '校对',
	'Column name' => '列名',
	'Type' => '类型',
	'Length' => '长度',
	'Auto Increment' => '自动增量',
	'Options' => '选项',
	'Save' => '保存',
	'Drop' => '丢弃',
	'Database has been dropped.' => '已丢弃数据库。',
	'Database has been created.' => '已创建数据库。',
	'Database has been renamed.' => '已重命名数据库。',
	'Database has been altered.' => '已更改数据库。',
	'Alter database' => '更改数据库',
	'Create database' => '创建数据库',
	'SQL command' => 'SQL命令',
	'Dump' => '导出',
	'Logout' => '注销',
	'database' => '数据库',
	'Use' => '使用',
	'No tables.' => '没有表。',
	'select' => '选择',
	'Create new table' => '创建新表',
	'Item has been deleted.' => '已删除项目。',
	'Item has been updated.' => '已更新项目。',
	'Item%s has been inserted.' => '已插入项目%s。',
	'Edit' => '编辑',
	'Insert' => '插入',
	'Save and insert next' => '保存并插入下一个',
	'Delete' => '删除',
	'Database' => '数据库',
	'Routines' => '子程序',
	'Indexes have been altered.' => '已更改索引。',
	'Indexes' => '索引',
	'Alter indexes' => '更改索引',
	'Add next' => '添加下一个',
	'Language' => '语言',
	'Select' => '选择',
	'New item' => '新建项',
	'Search' => '搜索',
	'Sort' => '排序',
	'descending' => '降序',
	'Limit' => '限定',
	'No rows.' => '没有行。',
	'Action' => '动作',
	'edit' => '编辑',
	'Page' => '页面',
	'Query executed OK, %d row(s) affected.' => '执行查询OK，%d 行受影响。',
	'Error in query' => '查询出错',
	'Execute' => '执行',
	'Table' => '表',
	'Foreign keys' => '外键',
	'Triggers' => '触发器',
	'View' => '视图',
	'Unable to select the table' => '不能选择该表',
	'Invalid CSRF token. Send the form again.' => '无效 CSRF 令牌。重新发送表单。',
	'Comment' => '注释',
	'Default values' => '默认值',
	'%d byte(s)' => '%d 字节',
	'No commands to execute.' => '没有命令执行。',
	'Unable to upload a file.' => '不能上传文件。',
	'File upload' => '文件上传',
	'File uploads are disabled.' => '文件上传被禁用。',
	'Routine has been called, %d row(s) affected.' => '子程序被调用，%d 行被影响。',
	'Call' => '调用',
	'No extension' => '没有扩展',
	'None of the supported PHP extensions (%s) are available.' => '没有支持的 PHP 扩展可用（%s）。',
	'Session support must be enabled.' => '会话必须被启用。',
	'Session expired, please login again.' => '会话已过期，请重新登录。',
	'Text length' => '文本长度',
	'Foreign key has been dropped.' => '已删除外键。',
	'Foreign key has been altered.' => '已更改外键。',
	'Foreign key has been created.' => '已创建外键。',
	'Foreign key' => '外键',
	'Target table' => '目标表',
	'Change' => '更改',
	'Source' => '源',
	'Target' => '目标',
	'Add column' => '增加列',
	'Alter' => '更改',
	'Add foreign key' => '添加外键',
	'ON DELETE' => 'ON DELETE',
	'ON UPDATE' => 'ON UPDATE',
	'Index Type' => '索引类型',
	'Column (length)' => '列（长度）',
	'View has been dropped.' => '已丢弃视图。',
	'View has been altered.' => '已更改视图。',
	'View has been created.' => '已创建视图。',
	'Alter view' => '更改视图',
	'Create view' => '创建视图',
	'Name' => '名称',
	'Process list' => '进程列表',
	'%d process(es) have been killed.' => '%d 个进程被终止',
	'Kill' => '终止',
	'Parameter name' => '参数名',
	'Database schema' => '数据库概要',
	'Create procedure' => '创建过程',
	'Create function' => '创建函数',
	'Routine has been dropped.' => '已丢弃子程序。',
	'Routine has been altered.' => '已更改子程序。',
	'Routine has been created.' => '已创建子程序。',
	'Alter function' => '更改函数',
	'Alter procedure' => '更改过程',
	'Return type' => '返回类型',
	'Add trigger' => '创建触发器',
	'Trigger has been dropped.' => '已丢弃触发器。',
	'Trigger has been altered.' => '已更改触发器。',
	'Trigger has been created.' => '已创建触发器。',
	'Alter trigger' => '更改触发器',
	'Create trigger' => '创建触发器',
	'Time' => '时间',
	'Event' => '事件',
	'%s version: %s through PHP extension %s' => '%s 版本：%s 通过 PHP 扩展 %s',
	'%d row(s)' => '%d 行',
	'Remove' => '移除',
	'Are you sure?' => '你确定吗？',
	'Privileges' => '权限',
	'Create user' => '创建用户',
	'User has been dropped.' => '已丢弃用户。',
	'User has been altered.' => '已更改用户。',
	'User has been created.' => '已创建用户。',
	'Hashed' => 'Hashed',
	'Column' => '列',
	'Routine' => '子程序',
	'Grant' => '授权',
	'Revoke' => '废除',
	'Logged as: %s' => '登录为：%s',
	'Too big POST data. Reduce the data or increase the %s configuration directive.' => '太大的 POST 数据。减少数据或者增加 %s 配置命令。',
	'Move up' => '上移',
	'Move down' => '下移',
	'Export' => '导出',
	'Tables' => '表',
	'Data' => '数据',
	'Output' => '输出',
	'open' => '打开',
	'save' => '保存',
	'Format' => '格式',
	'Functions' => '函数',
	'Aggregation' => '集合',
	'Event has been dropped.' => '已丢弃事件。',
	'Event has been altered.' => '已更改事件。',
	'Event has been created.' => '已创建事件。',
	'Alter event' => '更改事件',
	'Create event' => '创建事件',
	'Start' => '开始',
	'End' => '结束',
	'Every' => '每',
	'Status' => '状态',
	'On completion preserve' => '完成后保存',
	'Events' => '事件',
	'Schedule' => '调度',
	'At given time' => '在指定时间',
	'Tables have been truncated.' => '已清空表。',
	'Tables have been moved.' => '已转移表。',
	'Tables and views' => '表和视图',
	'Engine' => '引擎',
	'Collation' => '校对',
	'Data Length' => '数据长度',
	'Index Length' => '索引长度',
	'Data Free' => '数据空闲',
	'Rows' => '行数',
	',' => ',',
	'Analyze' => '分析',
	'Optimize' => '优化',
	'Check' => '检查',
	'Repair' => '修复',
	'Truncate' => '清空',
	'Move to other database' => '转移到其它数据库',
	'Move' => '转移',
	'Save and continue edit' => '保存并继续编辑',
	'original' => '原始',
	'%d item(s) have been affected.' => '%d 个项目受到影响。',
	'whole result' => '所有结果',
	'Tables have been dropped.' => '已丢弃表。',
	'Clone' => '克隆',
	'Maximum number of allowed fields exceeded. Please increase %s and %s.' => '超过最多允许的字段数量。请增加 %s 和 %s 。',
	'Partition by' => '分区类型',
	'Partitions' => '分区',
	'Partition name' => '分区名',
	'Values' => '值',
	'%d row(s) have been imported.' => '%d 行已导入。',
	'anywhere' => '任意位置',
	'CSV Import' => 'CSV 导入',
	'Import' => '导入',
	'Stop on error' => '出错时停止',
	'%.3f s' => '%.3f 秒',
	'$1-$3-$5' => '$1.$3.$5',
	'[yyyy]-mm-dd' => '[yyyy].mm.dd',
	'History' => '历史',
	'Variables' => '变量',
	'Source and target columns must have the same data type, there must be an index on the target columns and referenced data must exist.' => '源列和目标列必须具有相同的数据类型，在目标列上必须有一个索引并且引用的数据必须存在。',
	'Relations' => '关联信息',
	'Run file' => '运行文件',
	'Clear' => '清除',
	'Maximum allowed file size is %sB.' => '最多允许的文件大小为 %sB',
	'Numbers' => '数字',
	'Date and time' => '日期时间',
	'Strings' => '字符串',
	'Binary' => '二进制',
	'Lists' => '列表',
	'Editor' => '编辑器',
	'E-mail' => '电子邮件',
	'From' => '来自',
	'Subject' => '主题',
	'Send' => '发送',
	'%d e-mail(s) have been sent.' => '%d 封邮件已发送。',
	'Webserver file %s' => 'Web服务器文件 %s',
	'File does not exist.' => '文件不存在。',
	'%d in total' => '共计 %d',
	'Permanent login' => '保持登录',
	'Databases have been dropped.' => '已丢弃数据库。',
	'Search data in tables' => '在表中搜索数据',
	'schema' => '模式',
	'Schema' => '模式',
	'Alter schema' => '更改模式',
	'Create schema' => '创建模式',
	'Schema has been dropped.' => '已丢弃模式。',
	'Schema has been created.' => '已创建模式。',
	'Schema has been altered.' => '已更改模式。',
	'Sequences' => '序列',
	'Create sequence' => '创建序列',
	'Alter sequence' => '更改序列',
	'Sequence has been dropped.' => '已丢弃序列。',
	'Sequence has been created.' => '已创建序列。',
	'Sequence has been altered.' => '已更改序列。',
	'User types' => '用户类型',
	'Create type' => '创建类型',
	'Alter type' => '更改类型',
	'Type has been dropped.' => '已丢弃类型。',
	'Type has been created.' => '已创建类型。',
	'Double click on a value to modify it.' => '在值上双击类修改它。',
	'Increase Text length to modify this value.' => '增加文本长度以修改该值。',
	'Use edit link to modify this value.' => '使用编辑链接来修改该值。',
	'last' => '最后',
	'From server' => '来自服务器',
	'System' => '系统',
	'Select data' => '选择数据',
	'Show structure' => '显示结构',
	'empty' => '空',
	'Network' => '网络',
	'Geometry' => '几何图形',
	'File exists.' => '文件已存在。',
	'Attachments' => '附件',
	'%d query(s) executed OK.' => '%d 条查询已成功执行。',
	'Show only errors' => '仅显示错误',
	'Last page' => '末页',
	'Refresh' => '刷新',
	'Invalid schema.' => '非法模式。',
	'Please use one of the extensions %s.' => '请使用这些扩展中的一个：%s。',
	'now' => '现在',
	'ltr' => 'ltr',
);
